@@ -34,7 +34,6 @@
 
 // Qt includes
 #include <QColor>
-#include <QEvent>
 #include <QFont>
 #include <QGraphicsView>
 #include <QMouseEvent>
@@ -42,7 +41,6 @@
 #include <QPoint>
 #include <QStringList>
 #include <QTextDocument>
-#include <QTimer>
 #include <QElapsedTimer>
 
 // KDE includes
@@ -242,7 +240,7 @@ void DisplayIntro::buttonPressed(QGraphicsItem* item, int id)
     if (no == 13) {input0=KGameIO::MouseIO;input1=KGameIO::MouseIO;}
 
     // Emit signal
-    emit signalQuickStart(startPlayer, input0, input1, level);
+    Q_EMIT signalQuickStart(startPlayer, input0, input1, level);
   }
 }
 
