@@ -20,11 +20,9 @@
 
 #include "kgameprocess.h"
 
-#include <KRandomSequence>
-
+#include <QRandomGenerator>
 #include <QBuffer>
 #include <QDataStream>
-#include <QFile>
 
 #include <cassert>
 #include <cstdio>
@@ -38,7 +36,7 @@ class KGameProcessPrivate
 public:
     QFile rFile;
     QFile wFile;
-    KRandomSequence* mRandom;
+    QRandomGenerator* mRandom;
 };
 
 // ----------------------- Process Child ---------------------------
@@ -57,8 +55,7 @@ KGameProcess::KGameProcess()
 //          this, SLOT(receivedMessage(QByteArray,quint32)));
   connect(mMessageIO, &KMessageFilePipe::received, this, &KGameProcess::receivedMessage);
  
-  d->mRandom = new KRandomSequence;
-  d->mRandom->setSeed(0);
+  d->mRandom = new QRandomGenerator(QRandomGenerator::global()->generate());
 }
 KGameProcess::~KGameProcess() 
 {
@@ -123,20 +120,20 @@ void KGameProcess::receivedMessage(const QByteArray& receiveBuffer)
    case KGameMessage::IdTurn:
      qint8 b;
      stream >> b;
-     emit signalTurn(stream,(bool)b);
+     Q_EMIT signalTurn(stream,(bool)b);
    break;
    case KGameMessage::IdIOAdded:
      qint16 id;
      stream >> id;
-     emit signalInit(stream,(int)id);
+     Q_EMIT signalInit(stream,(int)id);
    break;
    default:
-      emit signalCommand(stream,msgid-KGameMessage::IdUser,receiver,sender);
+      Q_EMIT signalCommand(stream,msgid-KGameMessage::IdUser,receiver,sender);
    break;
  }
 }
 
-KRandomSequence* KGameProcess::random()
+QRandomGenerator* KGameProcess::random()
 {
   return d->mRandom;
 }
@@ -219,7 +216,7 @@ void KMessageFilePipe::exec()
        //msg.setRawData(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
        std::copy(mReceiveBuffer.begin()+2*sizeof(long),mReceiveBuffer.begin()+len, msg.begin());
 //  msg.duplicate(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
-       emit received(msg);
+       Q_EMIT received(msg);
        //msg.resetRawData(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
        mReceiveCount=0;
      }
