@@ -36,7 +36,6 @@
 #include <libkdegamesprivate/kgame/kplayer.h>
 
 // Local includes
-#include "kwin4global.h"
 #include "displayintro.h"
 #include "displaygame.h"
 #include "spritenotify.h"
@@ -532,7 +531,7 @@ void KWin4View::displayHint(int x, int y)
 // Slot called when a sprite animation move is done.
 void KWin4View::moveDone(QGraphicsItem* /*item*/, int mode)
 {
-  emit signalMoveDone(mode);
+  Q_EMIT signalMoveDone(mode);
 }
 
 
